package com.usky.fire.controller.web;


import com.usky.common.core.bean.ApiResult;
import com.usky.common.core.bean.CommonPage;
import com.usky.common.log.annotation.Log;
import com.usky.common.log.enums.BusinessType;
import com.usky.fire.domain.BaseCompany;
import com.usky.fire.service.BaseCompanyService;
import com.usky.fire.service.vo.CompanyDataVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 联网单位信息表 前端控制器
 * </p>
 *
 * @author JCB
 * @since 2022-08-23
 */
@RestController
@RequestMapping("/baseCompany")
public class BaseCompanyController {

    @Autowired
    private BaseCompanyService baseCompanyService;

    /**
     * 根据登录的用户查询所关联的单位下拉框
     *
     * @return
     */
    @GetMapping("userCompanySelect")
    public ApiResult<List<BaseCompany>> userCompanySelect() {
        return ApiResult.success(baseCompanyService.userCompanySelect());
    }

    /**
     * 单位管理-单位列表查询
     *
     * @param companyName  单位名称
     * @param organization 组织机构编码
     * @param pageNum      当前页
     * @param pageSize     每页条数
     * @return
     */
    @GetMapping("companyList")
    public ApiResult<CommonPage<Object>> companyList(@RequestParam(value = "companyName", required = false) String companyName,
                                                     @RequestParam(value = "organization", required = false) String organization,
                                                     @RequestParam(value = "pageNum", required = false, defaultValue = "1") Integer pageNum,
                                                     @RequestParam(value = "pageSize", required = false, defaultValue = "10") Integer pageSize) {
        return ApiResult.success(baseCompanyService.companyList(companyName, organization, pageNum, pageSize));
    }

    /**
     * 单位管理-修改
     *
     * @param companyDataVo
     * @return
     */
    @Log(title = "单位管理-修改", businessType = BusinessType.UPDATE)
    @PutMapping("updateCompany")
    public ApiResult<Void> updateCompany(@RequestBody CompanyDataVo companyDataVo) {
        baseCompanyService.updateCompany(companyDataVo);
        return ApiResult.success();
    }

    /**
     * 单位管理-删除
     *
     * @param id 主键ID
     * @return
     */
    @Log(title = "单位管理-删除", businessType = BusinessType.DELETE)
    @DeleteMapping("delCompany")
    public ApiResult<Void> delCompany(@RequestParam(value = "id") Integer id) {
        baseCompanyService.delCompany(id);
        return ApiResult.success();
    }


    /**
     * 企业自主管理-单位撒点
     *
     * @param streetTown  街镇
     * @param companyType 单位类型（1：重点单位、2：一般单位、3：九小场所、9：其他单位）
     * @return
     */
    @GetMapping("companyScatterer")
    public ApiResult<List<Object>> companyScatterer(@RequestParam(value = "streetTown", required = false) String streetTown,
                                                    @RequestParam(value = "companyType", required = false) String companyType) {
        return ApiResult.success(baseCompanyService.companyScatterer(streetTown, companyType));
    }


}

