package com.usky.fire.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.usky.common.core.bean.CommonPage;
import com.usky.common.core.util.StringUtils;
import com.usky.common.mybatis.core.AbstractCrudService;
import com.usky.fire.domain.BaseDevice;
import com.usky.fire.domain.DataRt;
import com.usky.fire.mapper.DataRtMapper;
import com.usky.fire.service.BaseDeviceService;
import com.usky.fire.service.BaseUserCompanyService;
import com.usky.fire.service.DataRtService;
import com.usky.fire.service.util.OnlineMethod;
import com.usky.fire.service.vo.RealTimeStatus;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 实时数据表 服务实现类
 * </p>
 *
 * @author JCB
 * @since 2022-08-24
 */
@Service
public class DataRtServiceImpl extends AbstractCrudService<DataRtMapper, DataRt> implements DataRtService {

    @Autowired
    private BaseUserCompanyService baseUserCompanyService;

    @Autowired
    private BaseDeviceService baseDeviceService;

    @Override
    public CommonPage<DataRt> dataRtList(String deviceCode, Integer systemType, Integer pageNum, Integer pageSize) {
        List<String> companyIdList = baseUserCompanyService.companyIdList();
        IPage<DataRt> page = new Page<>(pageNum, pageSize);
        if (CollectionUtils.isNotEmpty(companyIdList)) {
            LambdaQueryWrapper<DataRt> queryWrapper = Wrappers.lambdaQuery();
            queryWrapper.like(StringUtils.isNotBlank(deviceCode), DataRt::getDeviceCode, deviceCode)
                    .eq(DataRt::getSystemType, systemType)
                    .in(DataRt::getCompanyId, companyIdList);
            page = this.page(page, queryWrapper);
            for (int i = 0; i < page.getRecords().size(); i++) {
                page.getRecords().get(i).setDeviceTypeName(OnlineMethod.getDeviceTypeName(page.getRecords().get(i).getDeviceType()));
            }
        }
        return new CommonPage<>(page.getRecords(), page.getTotal(), pageSize, pageNum);
    }

    @Override
    public List<DataRt> dataRtListOne(String deviceCode, Integer systemType) {
        List<String> companyIdList = baseUserCompanyService.companyIdList();
        List<DataRt> list = new ArrayList<>();
        if (CollectionUtils.isNotEmpty(companyIdList)) {
            LambdaQueryWrapper<DataRt> queryWrapper = Wrappers.lambdaQuery();
            queryWrapper.like(StringUtils.isNotBlank(deviceCode), DataRt::getDeviceCode, deviceCode)
                    .eq(DataRt::getSystemType, systemType)
                    .in(DataRt::getCompanyId, companyIdList);
            list = this.list(queryWrapper);
            for (int i = 0; i < list.size(); i++) {
                list.get(i).setDeviceTypeName(OnlineMethod.getDeviceTypeName(list.get(i).getDeviceType()));
            }
        }
        return list;
    }

    @Override
    public List<DataRt> dataRt(String deviceCode){
        LambdaQueryWrapper<DataRt> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.select(DataRt::getDeviceCode, DataRt::getPorts, DataRt::getPortName, DataRt::getPortData,
                DataRt::getDataTime, DataRt::getContent)
                .eq(DataRt::getDeviceCode, deviceCode);
        List<DataRt> list = this.list(queryWrapper);
        return list;
    }

    @Override
    public RealTimeStatus deviceInfoData(String deviceCode){
        RealTimeStatus realTimeStatus = new RealTimeStatus();
        List<BaseDevice> baseDevices = baseDeviceService.deviceData(deviceCode);
        if (CollectionUtils.isNotEmpty(baseDevices)){
            List<DataRt> dataRtsList = this.dataRt(deviceCode);
            realTimeStatus.setDeviceName(baseDevices.get(0).getDeviceName());
            realTimeStatus.setInstallAddress(baseDevices.get(0).getInstallAddress());
            realTimeStatus.setDeviceType(baseDevices.get(0).getDeviceType());
            realTimeStatus.setStatusTime(dataRtsList.get(0).getDataTime());
            List<Object> list = new ArrayList<>();
            for (int i = 0; i < dataRtsList.size(); i++) {
                Map<String, Object> map = new HashMap<String, Object>();
                map.put("ports",dataRtsList.get(i).getPorts());
                map.put("portName",dataRtsList.get(i).getPortName());
                map.put("portData",dataRtsList.get(i).getPortData());
                map.put("content",dataRtsList.get(i).getContent());
                list.add(map);
            }
            realTimeStatus.setDataList(list);
        }
        return realTimeStatus;
    }

}
